========================================
``pyxrootd``: Python bindings for XRootD
========================================

``pyxrootd`` is a set of simple but pythonic bindings for
`XRootD <http://xrootd.slac.stanford.edu>`_. It is designed to make it easy to
interface with the XRootD client, by writing Python instead of having to write
C++.

For bug reporting and issue tracking, please see `the pyxrootd github issue
tracker <http://github.com/xrootd/xrootd-python/issues>`_

User Guide
==========

.. toctree::
   :numbered:
   :maxdepth: 2

   install
   gettingstarted
   examples

API Reference
=============

.. toctree::
   :numbered:
   :maxdepth: 1

   modules/client/filesystem
   modules/client/file
   modules/client/copyprocess
   modules/client/responses
   modules/client/flags
   modules/client/url
   modules/client/utils

